﻿

namespace Validation
{
    using System;
    using System.Collections.ObjectModel;
    using System.Globalization;
    using System.Text;
    using System.Windows.Controls;
    using System.Windows.Data;
    using System.Windows.Markup;

    /// <summary>
    /// This value converter could be used if binding a textblock (or any other UI element displaying text)
    /// within an error template to the validation errors collection of the adorned element. It creates a
    /// stringified error message out of the error contents of the validation errors.
    /// </summary>
    /// 
    [ValueConversion(typeof(ReadOnlyObservableCollection<ValidationError>), typeof(string))]
    public class ValidationErrorToErrorMessageConverter : MarkupExtension, IValueConverter
    {
        private ValidationErrorToErrorMessageConverter _mySelf;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="serviceProvider"></param>
        /// <returns></returns>
        public override object ProvideValue(IServiceProvider serviceProvider)
        {
            if (_mySelf == null)
            {
                _mySelf = new ValidationErrorToErrorMessageConverter();
            }
            return _mySelf;
        }

        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            ReadOnlyObservableCollection<ValidationError> errors =
                value as ReadOnlyObservableCollection<ValidationError>;

            StringBuilder errorMessage = new StringBuilder();
            if (null != errors)
            {
                foreach (var error in errors)
                {
                    errorMessage.AppendLine(error.ErrorContent.ToString());
                }

                return errorMessage;
            }

            return errorMessage;
        }

        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
